==> claromentis-framework-8.13.65-b8aa1bfb.zip: web/intranet/core/classes/Event/LazyResolver.php <==
<?php
namespace Claromentis\Core\Event;

$GLOBALS["__65da1b1ec" . "2d6653e8a0a" . "b7848e53621" . "5"] = (@$GLOBALS["__65da1b1ec2d6653e8a" . "0ab7848e536215"] ?: array()) + array("_5e30c4717ce" . "d36cff9e93e1" . "9a5c576cc" => base64_decode("aXN" . "fc3" . "Rya" . "W5n"), "_ae76ef27" . "ae5b48757" . "f71a20271" . "8b5e5e" => base64_decode("Y2FsbF91c2VyX2Z1bm" . "NfYXJyYXk="));
use Pimple\Container;
use Symfony\Component\EventDispatcher\EventDispatcherInterface as BaseEventDispatcherInterface;















class LazyResolver
{
    protected $events_list;
    protected $container;
    protected $service_name;
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    public function __construct(Container $app, $service_name, $_0e556da531c586bbe7e57a92634addf5)
    {
        $this->container = $app;
        $this->events_list = $_0e556da531c586bbe7e57a92634addf5;
        $this->service_name = $service_name;
    }
    
    
    
    
    
    
    public function subscribe(BaseEventDispatcherInterface $_b497ce6f2af10f67516aed0ecf34d8cf)
    {
        
        
        foreach ($this->events_list as $_2cf093f28f4c7e718a5e8af628894c7b => $_4c4d12d3e4f6cac68e3eecffe9887915) {
            if ($GLOBALS["__65da1b1ec" . "2d6653e8a0a" . "b7848e53621" . "5"]["_5e30c4717ced36cff9e93e1" . "9a5c576cc"]($_4c4d12d3e4f6cac68e3eecffe9887915)) {
                $_b497ce6f2af10f67516aed0ecf34d8cf->addListener($_2cf093f28f4c7e718a5e8af628894c7b, array($this, $_4c4d12d3e4f6cac68e3eecffe9887915));
            } elseif ($GLOBALS["__65da1b1ec2d6653e8a0ab" . "7848e536215"]["_5e30c4717ced36cff" . "9e93e19a5c576cc"]($_4c4d12d3e4f6cac68e3eecffe9887915[0])) {
                $_b497ce6f2af10f67516aed0ecf34d8cf->addListener($_2cf093f28f4c7e718a5e8af628894c7b, array($this, $_4c4d12d3e4f6cac68e3eecffe9887915[0]), isset($_4c4d12d3e4f6cac68e3eecffe9887915[1]) ? $_4c4d12d3e4f6cac68e3eecffe9887915[1] : 0);
            } else {
                foreach ($_4c4d12d3e4f6cac68e3eecffe9887915 as $_c44578bb3769209a3b3733819fd02602) {
                    $_b497ce6f2af10f67516aed0ecf34d8cf->addListener($_2cf093f28f4c7e718a5e8af628894c7b, array($this, $_c44578bb3769209a3b3733819fd02602[0]), isset($_c44578bb3769209a3b3733819fd02602[1]) ? $_c44578bb3769209a3b3733819fd02602[1] : 0);
                }
            }
        }
        unset($this->events_list);
        
        
    }
    public function __call($_dfd42320291c688f32c87c7179a5604e, $arguments)
    {
        $_4d348406673ac4fa7aebc6394e363899 = $this->container[$this->service_name];
        return $GLOBALS["__65da1b1ec2d6653e8a0ab7848e5" . "36215"]["_ae76ef27ae5b48757f71a2027" . "18b5e5e"]([$_4d348406673ac4fa7aebc6394e363899, $_dfd42320291c688f32c87c7179a5604e], $arguments);
    }
}

==> claromentis-framework-9.6.5-177028fb.zip: web/intranet/core/classes/Event/LazyResolver.php <==
<?php
namespace Claromentis\Core\Event;

$GLOBALS["__65da1b1ec2" . "d6653e8a0ab7" . "848e536215"] = (@$GLOBALS["__65da1b1ec2d" . "6653e8a0ab784" . "8e536215"] ?: array()) + array("_ae76ef27ae5b48757f71a202718b5e" . "5e" => base64_decode("Y2FsbF91" . "c2VyX2Z1" . "bmNfYXJy" . "YXk="), "_5e30c4717c" . "ed36cff9e93" . "e19a5c576cc" => base64_decode("aXNfc3RyaW" . "5n"));
use Pimple\Container;
use Symfony\Component\EventDispatcher\EventDispatcherInterface as BaseEventDispatcherInterface;















class LazyResolver
{
    protected $events_list;
    protected $container;
    protected $service_name;
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    public function __construct(Container $app, $service_name, $_0e556da531c586bbe7e57a92634addf5)
    {
        $this->container = $app;
        $this->events_list = $_0e556da531c586bbe7e57a92634addf5;
        $this->service_name = $service_name;
    }
    
    
    
    
    
    
    public function subscribe(BaseEventDispatcherInterface $_b497ce6f2af10f67516aed0ecf34d8cf)
    {
        
        
        foreach ($this->events_list as $_2cf093f28f4c7e718a5e8af628894c7b => $_4c4d12d3e4f6cac68e3eecffe9887915) {
            if ($GLOBALS["__65da1b1ec2d6653e8a0ab7848e5" . "36215"]["_5e30c4717ced36cff9e93e19a5c576c" . "c"]($_4c4d12d3e4f6cac68e3eecffe9887915)) {
                $_b497ce6f2af10f67516aed0ecf34d8cf->addListener($_2cf093f28f4c7e718a5e8af628894c7b, array($this, $_4c4d12d3e4f6cac68e3eecffe9887915));
            } elseif ($GLOBALS["__65da1b1ec2d665" . "3e8a0ab7848e5362" . "15"]["_5e30c4717ced36cff9e93" . "e19a5c576cc"]($_4c4d12d3e4f6cac68e3eecffe9887915[0])) {
                $_b497ce6f2af10f67516aed0ecf34d8cf->addListener($_2cf093f28f4c7e718a5e8af628894c7b, array($this, $_4c4d12d3e4f6cac68e3eecffe9887915[0]), isset($_4c4d12d3e4f6cac68e3eecffe9887915[1]) ? $_4c4d12d3e4f6cac68e3eecffe9887915[1] : 0);
            } else {
                foreach ($_4c4d12d3e4f6cac68e3eecffe9887915 as $_c44578bb3769209a3b3733819fd02602) {
                    $_b497ce6f2af10f67516aed0ecf34d8cf->addListener($_2cf093f28f4c7e718a5e8af628894c7b, array($this, $_c44578bb3769209a3b3733819fd02602[0]), isset($_c44578bb3769209a3b3733819fd02602[1]) ? $_c44578bb3769209a3b3733819fd02602[1] : 0);
                }
            }
        }
        unset($this->events_list);
        
        
    }
    public function __call($_dfd42320291c688f32c87c7179a5604e, $arguments)
    {
        $_4d348406673ac4fa7aebc6394e363899 = $this->container[$this->service_name];
        return $GLOBALS["__65da1b1ec2d6653e8a0" . "ab7848e536215"]["_ae76ef27a" . "e5b48757f7" . "1a202718b5" . "e5e"]([$_4d348406673ac4fa7aebc6394e363899, $_dfd42320291c688f32c87c7179a5604e], $arguments);
    }
}
